@@ -4,8 +4,8 @@ module Grape
   class Entity
     module Delegator
       class HashObject < Base
-        def delegate(attribute)
-          object[attribute]
+        def delegate(attribute, hash_access: :to_sym)
+          object[attribute.send(hash_access)]
         end
       end
     end
